copyWithNull property
Set copyWithNull to true if you want to use copyWithNull function that allows you to nullify the fields. E.g. myInstance.copyWithNull(id: true, name: true). Default is false.
Implementation
final bool? copyWithNull;
Set copyWithNull to true if you want to use copyWithNull function that allows you to nullify the fields. E.g. myInstance.copyWithNull(id: true, name: true). Default is false.
final bool? copyWithNull;