immutableFields property
Treats all fields as immutable by default when set to true.
Fields can still opt out using @CopyWithField(immutable: false).
Defaults to false.
Implementation
final bool? immutableFields;
Treats all fields as immutable by default when set to true.
Fields can still opt out using @CopyWithField(immutable: false).
Defaults to false.
final bool? immutableFields;