immutable property
Indicates that the field should be hidden in the generated copyWith and
copyWithNull methods. By setting this flag to true the field will
always be copied as it is and excluded from the generated interfaces.
Default is false.
Implementation
final bool? immutable;